clear
close all
% This is a matlab script that generates the input data

% the configuation approximately the ISOMIP experiment no. 1
% then cur the iceshelf and add real sea ice forcings
% need Shapiro filter function shapiro1.m to smoothen iceshelf topography
% no need to require matlab functions for equation of state

%% dx dy files
% CENTERED Dimensions of grid, high resolution region
nx=200;
ny=400;
nz=50;

delta_z = 10;

dlat = 0.01;
dlon = 0.04;

acc = 'real*8';
ieee = 'b';

%% Grid file
dxfile = dlon*ones(1,nx);
dyfile = dlat*ones(1,ny);
dzfile = delta_z*ones(1,nz);


% The above are the ones with uniform high resolution
% Now we add the one with nonuniform linearly growing grid
% On both west and east sides of x, and north of y
ny_north_linear_ramp = 80;
ny_linear_ramp_added = ny_north_linear_ramp + ny; % 400 + 80

nx_west = 25;
nx_east = 25;
nx_linear_ramp_added = nx+nx_west+nx_east; % 200 + 25 + 25

dlon_max = 0.1;
dlat_max = 0.04;

west_add = linspace(dlon_max,dlon,nx_west);
east_add = linspace(dlon,dlon_max,nx_east);
north_add = linspace(dlat, dlat_max, ny_north_linear_ramp);

dxfile = [west_add dxfile east_add];
dyfile = [dyfile north_add];

%% Add the west and east lengthen layers, keep the same north dimension
% symmetric, making the total nx to be 360
% 200 + 25*2 + 55*2
nx_west_lengthen = 55;
nx_east_lengthen = 55;

west_add_lengthen = linspace(dlon_max,dlon_max,nx_west_lengthen);
east_add_lengthen = linspace(dlon_max,dlon_max,nx_east_lengthen);
dxfile = [west_add_lengthen dxfile east_add_lengthen];


% print out the bin files
fid=fopen('dxfile.bin','w','b'); fwrite(fid,dxfile,acc);fclose(fid);
fid=fopen('dyfile.bin','w','b'); fwrite(fid,dyfile,acc);fclose(fid);
fid=fopen('dzfile.bin','w','b'); fwrite(fid,dzfile,acc);fclose(fid);


%% longtitude and latitude vectors at face g and center c
northen_end_lat = -77; % starting at -77 lat

latg = northen_end_lat+cumsum(dyfile);
latc = latg+dyfile/2;

long = cumsum(dxfile); % changed from -80 to -77
lonc = long+dxfile/2;

%% Bathymetry parameters

% construct the center high resolution part first
% Point out the land part, bathy=0
% ice shelf part is about 50 points in x, 100 points in y

% H- Nominal depth of model (meters)
H = -500;
bathy_high_reso = ones(nx,ny)*H;
west_land_index = 76;
east_land_index = 127;

west_iceshelf_index = west_land_index+1;
east_iceshelf_index = east_land_index-1;

% bathy_high_reso(1,:) = 0; % Wall on the west side
bathy_high_reso(:,1) = 0; % Wall on the south side

iceshelf_north_end_index = 100; % important, indicate land end
%
bathy_high_reso(1:(west_land_index), 1:iceshelf_north_end_index) = 0;
bathy_high_reso((east_land_index):nx, 1:iceshelf_north_end_index) = 0;
%

%% Round up the land corners

% Point land northwest
land_radius = 20;
i_center = west_land_index-land_radius;
j_center = iceshelf_north_end_index-land_radius;
for i = i_center:(west_land_index)
    for j = j_center:iceshelf_north_end_index
        if ((i-i_center)^2+(j-j_center)^2) > land_radius^2
            bathy_high_reso(i,j) = H;
        end
    end
end

% Point land northeast
i_center = east_land_index+land_radius;
j_center = iceshelf_north_end_index-land_radius;
for i = (east_land_index):i_center
    for j = j_center:iceshelf_north_end_index
        if ((i-i_center)^2+(j-j_center)^2) > land_radius^2
            bathy_high_reso(i,j) = H;
        end
    end
end


% Point iceshelf southwest
i_center = west_iceshelf_index+land_radius;
j_center = 2+land_radius;
for i = west_iceshelf_index:i_center
    for j = 2:j_center
        if ((i-i_center)^2+(j-j_center)^2) > land_radius^2
            bathy_high_reso(i,j) = 0;
        end
    end
end


% Point iceshelf southeast
i_center = east_iceshelf_index-land_radius;
j_center = 2+land_radius;
for i = i_center:east_iceshelf_index
    for j = 2:j_center
        if ((i-i_center)^2+(j-j_center)^2) > land_radius^2
            bathy_high_reso(i,j) = 0;
        end
    end
end

%% Bathymetry: Add the parts with low resolution
west_part = H*ones(nx_west,ny_linear_ramp_added);
east_part = H*ones(nx_east,ny_linear_ramp_added);
north_part_middle = H*ones(nx,ny_north_linear_ramp);
% For the north - only add the middle parts without the above west and east

bathy_combined = H*ones(nx_linear_ramp_added,ny_linear_ramp_added);

bathy_combined(1:nx_west, 1:ny_linear_ramp_added) = west_part;
bathy_combined(nx_west+1:nx_west+nx, 1:ny) = bathy_high_reso;
bathy_combined(nx_west+nx+1:nx_linear_ramp_added, 1:ny_linear_ramp_added) = east_part;
bathy_combined(nx_west+1:nx_west+nx, ny+1:ny_linear_ramp_added) = north_part_middle;

% modify and add new land with bathy_combined=0
bathy_combined(1:nx_west, 1:iceshelf_north_end_index) = 0;
bathy_combined(nx_west+nx+1:nx_linear_ramp_added, 1:iceshelf_north_end_index) = 0;

%% Bathymetry: Add the parts in the west and east with lengthen layers
west_lengthen = H*ones(nx_west_lengthen,ny_linear_ramp_added);
east_lengthen = H*ones(nx_east_lengthen,ny_linear_ramp_added);
bathy_combined = [west_lengthen; bathy_combined; east_lengthen];

% modify and add new land with bathy_combined=0
bathy_combined(1:nx_west_lengthen, 1:iceshelf_north_end_index) = 0;
bathy_combined((nx_west+nx+nx_west_lengthen+nx_east+1):(nx_linear_ramp_added+nx_west_lengthen+nx_east_lengthen), 1:iceshelf_north_end_index) = 0;


% Add the wall on the south boundary to avoid periodic BC
% bathy_combined(1,:) = 0; % Wall on the west side
bathy_combined(:,1) = 0; % Wall on the south side

%% 20210905 - add coast to the left of the ice shelf
% to mimic Cape Washington in the Terra Nova Bay
% the original version was in the %% add packed ice section to modify icetopo
flag_add_cape_left = 1;

if flag_add_cape_left == 1
    
    % add on 20200210- pack ice area to the west of ice shelf coastline
    % ramp and then constant with width 1 deg
    % define the turning point northwest of the ice shelf as turn_point, with
    % index in_x and in_y
    turn_point_in_x = 100; % adjustment
    turn_point_in_y = iceshelf_north_end_index+75; % 1-deg in width
    
    % the point starting to turn along the coastline of ice shelf
    coast_start_point_in_x = 120;
    coast_start_point_in_y = iceshelf_north_end_index+1;
        
    % the rectangular part
    bathy_combined(1:turn_point_in_x, coast_start_point_in_y:turn_point_in_y) = 0;
    
    % the triangular part- linear connection
    array_lim_packice_in_y = linspace(turn_point_in_y, coast_start_point_in_y,...
        (coast_start_point_in_x-turn_point_in_x+1));
    % round down to integer
    array_lim_packice_in_y = round(array_lim_packice_in_y);
    
    array_in_x_between_coast_and_turn = turn_point_in_x:coast_start_point_in_x;
    for i = 1:length(array_in_x_between_coast_and_turn)
        bathy_combined(array_in_x_between_coast_and_turn(i), coast_start_point_in_y:array_lim_packice_in_y(i)) = 0;
    end
    
    
end


fid=fopen('bathy.box','w','b'); fwrite(fid,bathy_combined,acc);fclose(fid);


%% Modified Ice shelf according to ISOMIP exp2

% A more smooth ice line with Shapiro filter
% -77 to -76 latitude, with -400m to -200m, then reduce to 0m at -76 latitude
% Then smooth the pointy part for the intersaction of two slopes

Hmin = -400; % deepest point of cavern
Hmax = -200; % shallowest point of cavern

pointy_latc_in = iceshelf_north_end_index-9;
dHdx = (Hmax-Hmin)/(-latg(1)-(-latc(pointy_latc_in)));

ice_line = (Hmin + dHdx*(latc-latg(1)));
ice_line(pointy_latc_in:(iceshelf_north_end_index+1)) = (ice_line(pointy_latc_in)-0)/(latc(pointy_latc_in)-...
    latc((iceshelf_north_end_index+1)))*(latc(pointy_latc_in:(iceshelf_north_end_index+1))-latc(pointy_latc_in))+ice_line(pointy_latc_in);


% Smoothen iceshelf topo for 50 times
smoothen_times = 50;

for i = 1:smoothen_times
    ice_line(1:(iceshelf_north_end_index-3)) = shapiro1(ice_line(1:(iceshelf_north_end_index-3)), 2, 1);
end

ice_line(:,(iceshelf_north_end_index+1):end) = 0; % ocean part, no iceshelf

% Plot iceshelf shape to check
figure
plot(latc, ice_line);
xlabel('latitude','fontsize',16)
ylabel('depth (m)','fontsize',16)
title('iceshelf shape','fontsize',18)
axis tight

icetopo = ones(size(bathy_combined,1),1)*ice_line;

% eliminate the part over land
icetopo(bathy_combined==0) = 0;


%% add ice tongue section
add_ice_tongue = 1;

if add_ice_tongue == 1
    % 20191231- based on 20191228 version
    % add iceshelf northward intrusion at the eastern edge of iceshelf
    % 1 deg lat in length
    % icetopo(226,(iceshelf_north_end_index+1):(iceshelf_north_end_index+101)) = -20;
    
    
    % 20200107- add an ice tongue 1deg (25 points) in lon, 1 deg (100 points) in
    % lat
    % points number 227 to 252 in x
    % same shape in y as the iceshelf
    
    
    % 20200602- change ice tongue length and then smooth, flag added
    % flag == 1, change ice tongue length
    % flag == 0, ice tongue shape similar to ice shelf
    change_ice_tongue_length_flag = 1;
    
    if change_ice_tongue_length_flag == 0
        
        % original version- ice tongue similar shape to ice shelf
        icetongue_line = ice_line(1:100);
        for i = 227:252
            icetopo(i,(iceshelf_north_end_index+1):(iceshelf_north_end_index+100)) = icetongue_line;
        end
        
    end
    
    % change the length of ice tongue- mostly shorten it
    if change_ice_tongue_length_flag ~= 0
        
        icetongue_length_in = 100; % change ice tongue length
        icetongue_line = ice_line(1:icetongue_length_in);
        
%         % smoothening is not useful here, since the length is short
%         for i = 1:smoothen_times
%             icetongue_line(1:(length(icetongue_line)-3)) = shapiro1(icetongue_line(1:(length(icetongue_line)-3)), 2, 1);
%         end
        
        for i = 227:252
            icetopo(i,(iceshelf_north_end_index+1):(iceshelf_north_end_index+length(icetongue_line))) = icetongue_line;
        end
        
    end
        
end


%% add packed ice section
add_packed_ice = 0;

if add_packed_ice == 1
    
    % add on 20200210- pack ice area to the west of ice shelf coastline
    % ramp and then constant with width 1 deg
    % define the turning point northwest of the ice shelf as turn_point, with
    % index in_x and in_y
    turn_point_in_x = 100; % adjustment
    turn_point_in_y = iceshelf_north_end_index+75; % 1-deg in width
    
    % the point starting to turn along the coastline of ice shelf
    coast_start_point_in_x = 120;
    coast_start_point_in_y = iceshelf_north_end_index+1;
    
    pack_ice_thick = -500; % packice thickness
    
    % the rectangular part
    icetopo(1:turn_point_in_x, coast_start_point_in_y:turn_point_in_y) = pack_ice_thick;
    
    % the triangular part- linear connection
    array_lim_packice_in_y = linspace(turn_point_in_y, coast_start_point_in_y,...
        (coast_start_point_in_x-turn_point_in_x+1));
    % round down to integer
    array_lim_packice_in_y = round(array_lim_packice_in_y);
    
    array_in_x_between_coast_and_turn = turn_point_in_x:coast_start_point_in_x;
    for i = 1:length(array_in_x_between_coast_and_turn)
        icetopo(array_in_x_between_coast_and_turn(i), coast_start_point_in_y:array_lim_packice_in_y(i)) = pack_ice_thick;
    end
    
    %
    
end

fid=fopen('icetopo.exp1','w','b'); fwrite(fid,icetopo,acc);fclose(fid);
% fid=fopen('pload.exp1','w','b'); fwrite(fid,-icetopo,acc);fclose(fid);



%% wind and air external forcings

% not used: vwind1 = 20*ones(size(bathy_combined)); % Wind all over

% Wind within rectangle, decaying linearly outwards
vwind1 = zeros(size(bathy_combined));

wind_main = 20;
wind_rest = 0;

% 50 grid points in x for the main field
xwind1 = 157; xwind2 = 206;
% 100 grid points in y for the main field
ywind1 = (iceshelf_north_end_index+1); ywind2 = ywind1+100;

vwind1(xwind1:xwind2, ywind1:ywind2) = wind_main;

wind_decay_length = 50;
wind_decay_frac = 1-(1:wind_decay_length)/wind_decay_length;

for k = 1:length(wind_decay_frac)
    vwind1(xwind1-k:xwind2+k, ywind2+k) = wind_decay_frac(k)*(wind_main-wind_rest)+wind_rest;
    vwind1(xwind1-k, ywind1:ywind2+k) = wind_decay_frac(k)*(wind_main-wind_rest)+wind_rest;
    vwind1(xwind2+k, ywind1:ywind2+k) = wind_decay_frac(k)*(wind_main-wind_rest)+wind_rest;
end


% relaxation points 3 cells each boundary for winds
% not really used here
vwind1(1:3,:) = 0;
vwind1((end-2):end,:) = 0;
vwind1(:,(end-2):end) = 0;

%% 20200322 overwrite- change the V-wind to a half-oval shape
mid_xwind12 = (xwind1+xwind2)/2;
vwind1 = zeros(size(bathy_combined));

wind_decay_frac_oval_flip = flip((1:wind_decay_length)/wind_decay_length);
for ki = length(wind_decay_frac_oval_flip):(-1):1
    for xi = 1:size(vwind1,1)
        for yi = ywind1:size(vwind1,2)
            
            if (xi-mid_xwind12)^2/(mid_xwind12-xwind1+ki)^2 + (yi-ywind1)^2/(ywind2-ywind1+ki)^2 <= 1
                vwind1(xi,yi) = wind_main*wind_decay_frac_oval_flip(ki);
            end
        end
    end
end

%% Switch between fluctuating wind and constant wind
wind_is_fluc = 1;
wind_is_const = (~wind_is_fluc);


% 41-1=40 records for wind field
% the 1st one is 0 all over; there is a linear interpolation in time
% 5 day for each period, 200 days for input

% fluctuating wind

% 12-hour period, 200 days


%% 20200316- modified with sporadic Vwind and Uwind

% if wind_is_fluc == 1
%
%     for j = 1:801
%         if ismember(j,(1:2:801))
%             vwind(:,:,j) = zeros(size(vwind1));
%         else
%             vwind(:,:,j) = vwind1*2; % fluctuating to 40 m/s
%         end
%     end
%
% end

load wind_scale_6hr_200days_sporadic_data.mat

if wind_is_fluc == 1
    
    for j = 1:801
        if j == 1
            vwind(:,:,j) = zeros(size(vwind1)); % first period is time
        else
            vwind(:,:,j) = vwind1*2 *wind_value_scale_6hr(j) /40*40; % fluctuating to 50 m/s
        end
    end
    
end

% constant wind
if wind_is_const == 1
    
    for j = 1:41
        
        if j == 1
            vwind(:,:,j) = zeros(size(vwind1)); % first period is time ramp
        else
            vwind(:,:,j) = vwind1; % 20m/s constant wind
        end
    end
end


fid=fopen('vwind.bin','w','b'); fwrite(fid,vwind,acc);fclose(fid);


add_Uwind = 1;

if add_Uwind == 1
    % 20200116- add uwind=-10m/s all over, constant all the time
    uwind_value = -10;
    uwind1 = uwind_value*ones(size(bathy_combined));
    
    % % 20200123- uwind is 0 within the sea ice sponge zone
    % uwind1(:,(end-2):end) = 0;
    % uwind1(1:3,:) = 0;
    % uwind1((end-2):end,:) = 0;
    
    % 2020/06/25- add a switch to uniform Uwind in the coastal region
    
    Uwind_coastal_uniform_flag = 1; % flag to switch
    
    if Uwind_coastal_uniform_flag == 1
        uwind_1d = [linspace(0,0,100) linspace(uwind_value,uwind_value,100) linspace(uwind_value,uwind_value,250) linspace(uwind_value,0,30)];
    end
    
    if Uwind_coastal_uniform_flag ~= 1
        % add on 01/30/2020- uwind 0to10m/s from 76S to 75S
        % uwind 10to0m/s from 72S to the northern end, 71S
        uwind_1d = [linspace(0,0,100) linspace(0,uwind_value,100) linspace(uwind_value,uwind_value,250) linspace(uwind_value,0,30)];
    end
    
    uwind1 = ones(size(bathy_combined,1),1)*uwind_1d;
    uwind1((end-2):end,:) = 0; % eastern BC is 0 for uwind, 3 grids
    
    % 20210628 - add ramp of Uwind near all the north/east/west boundaries
    add_uwind_BC_ramp_flag = 1;
    if add_uwind_BC_ramp_flag == 1
        uwind1 = function_boundary_ramp_inwards_2d_setup(bathy_combined,0,uwind_value,0,30);
        uwind1(30:(end-30+1),1:iceshelf_north_end_index) = uwind_value;
    end
    
    
    % 20200611- Uwind const or fluc switch, both 6-hour interval
    
    % if Uwind_is_fluc == 0, choose constant Uwind
    % remember to confirm the period length in data.exf
    % and also confirm data.obcs setup with uice and vice BC
    Uwind_is_fluc = 0;
    
    % default: const Uwind
    for j = 1:801
        if j == 1
            uwind(:,:,j) = zeros(size(uwind1)); % first period is time
        else
            uwind(:,:,j) = uwind1 * 1; % constant to 10 m/s
        end
    end
    
    % uwind2 = uwind1;
    %
    % uwind(:,:,1) = uwind1;
    % uwind(:,:,2) = uwind2;
    
    if Uwind_is_fluc == 1
        
        for j = 1:801
            if j == 1
                uwind(:,:,j) = zeros(size(uwind1)); % first period is time
            else
                uwind(:,:,j) = uwind1 *wind_value_scale_6hr(j); % fluctuating to 40 m/s
            end
        end
        
    end
    
    fid=fopen('uwind.bin','w','b'); fwrite(fid,uwind,acc);fclose(fid);
    
end


%% Airtemp- varies linearly inwards in west/east/north relaxation region

airtemp_rest = 0;
airtemp_main = -20;
airtemp_const_rest_length = 0;
airtemp_ramp_to_center_length = 0;
airtemp1 = function_boundary_ramp_inwards_2d_setup(bathy_combined,airtemp_rest,airtemp_main,airtemp_const_rest_length,airtemp_ramp_to_center_length);

airtemp2 = airtemp1;
airtemp(:,:,1) = airtemp1;
airtemp(:,:,2) = airtemp2;

fid=fopen('airtempfield.bin','w','b'); fwrite(fid,airtemp,acc);fclose(fid);

%% Humidity field- const everywhere
humidfield_value = 0.0005;
humidfield1 = humidfield_value*ones(size(bathy_combined));
humidfield2 = humidfield1;

humidfield(:,:,1) = humidfield1;
humidfield(:,:,2) = humidfield2;

fid=fopen('humidfield.bin','w','b'); fwrite(fid,humidfield,acc);fclose(fid);

%% Longwave radiation field- linearly varies the same way as Air temp
lwdownfield_main = 200;
lwdownfield_rest = 270;

lwdownfield1 = function_boundary_ramp_inwards_2d_setup(bathy_combined,lwdownfield_rest,lwdownfield_main,airtemp_const_rest_length,airtemp_ramp_to_center_length);


lwdownfield2 = lwdownfield1;
lwdownfield(:,:,1) = lwdownfield1;
lwdownfield(:,:,2) = lwdownfield2;

fid=fopen('lwdownfield.bin','w','b'); fwrite(fid,lwdownfield,acc);fclose(fid);

%% Sea ice initial files
SIarea_init_value = 1;
SIarea_init = SIarea_init_value*ones(size(bathy_combined));
SIarea_init(bathy_combined == 0) = 0; % get rid of the land
SIarea_init(icetopo ~= 0) = 0; % get rid of ice shelf, ice tongue and pack ice
fid=fopen('SIarea_init.bin','w','b'); fwrite(fid,SIarea_init,acc);fclose(fid);

SIheff_init_value = 0.5;
SIheff_init = SIheff_init_value*ones(size(bathy_combined));
SIheff_init(bathy_combined == 0) = 0; % get rid of the land
SIheff_init(icetopo ~= 0) = 0; % get rid of ice shelf, ice tongue and pack ice
fid=fopen('SIheff_init.bin','w','b'); fwrite(fid,SIheff_init,acc);fclose(fid);

%% Empty external forcing- use 0 eyerywhere
empty2dfield1 = 0.0*ones(size(bathy_combined));
empty2dfield2 = empty2dfield1;

empty2dfield(:,:,1) = empty2dfield1;
empty2dfield(:,:,2) = empty2dfield2;

fid=fopen('empty2dfield.bin','w','b'); fwrite(fid,empty2dfield,acc);fclose(fid);


%% 2020/05/22- Switch sea ice boundary conditions
% depending on whether Uwind is on or off

% Original sea ice BC by default

%% Seaice OBCS Nx/y * time levels
% ice area = 1 west east, with decay northward
% 20 points used for decaying, about 0.8deg in lat
% north point is 0
ice_area = 1;
ice_area_bc_decay_num = 20;
ice_area_bc_decay = linspace(ice_area,0,ice_area_bc_decay_num);
ice_area_bc_decay = ice_area_bc_decay';

iceOBCSawest1 = ice_area*ones(size(bathy_combined,2),1);
iceOBCSawest1((end-ice_area_bc_decay_num+1):end)=ice_area_bc_decay;
iceOBCSawest1(1:iceshelf_north_end_index,:) = 0; % eliminate the land part
iceOBCSawest2 = iceOBCSawest1;
iceOBCSawest(:,1) = iceOBCSawest1*0.0;
iceOBCSawest(:,2) = iceOBCSawest2*0.0;
fid=fopen('iceOBCSawest.bin','w','b'); fwrite(fid,iceOBCSawest,acc);fclose(fid);


iceOBCSaeast = iceOBCSawest;
fid=fopen('iceOBCSaeast.bin','w','b'); fwrite(fid,iceOBCSaeast,acc);fclose(fid);

iceOBCSanorth1 = 0*ones(size(bathy_combined,1),1);
iceOBCSanorth2 = iceOBCSanorth1;
iceOBCSanorth(:,1) = iceOBCSanorth1;
iceOBCSanorth(:,2) = iceOBCSanorth2;
fid=fopen('iceOBCSanorth.bin','w','b'); fwrite(fid,iceOBCSanorth,acc);fclose(fid);


% ice thickness
% enforcing the same pattern as ice area bc

iceOBCShwest = 0.0*iceOBCSawest;
fid=fopen('iceOBCShwest.bin','w','b'); fwrite(fid,iceOBCShwest,acc);fclose(fid);

iceOBCSheast = 0.0*iceOBCSaeast;
fid=fopen('iceOBCSheast.bin','w','b'); fwrite(fid,iceOBCSheast,acc);fclose(fid);

iceOBCShnorth = 0.0*iceOBCSanorth;
fid=fopen('iceOBCShnorth.bin','w','b'); fwrite(fid,iceOBCShnorth,acc);fclose(fid);


%% with Uwind condition, change sea ice BC
if add_Uwind == 1
    
%     %% Seaice OBCS Nx/y * time levels
%     % ice area = 1 west east, with decay northward
%     % 20 points used for decaying, about 0.8deg in lat
%     % north point is 0
%     ice_area = 1;
%     ice_area_bc_decay_num = 20;
%     ice_area_bc_decay = linspace(ice_area,0,ice_area_bc_decay_num);
%     ice_area_bc_decay = ice_area_bc_decay';
%     
%     iceOBCSawest1 = ice_area*ones(size(bathy_combined,2),1);
%     % 20200124- eliminate the decaying sea ice boundary- after adding u-wind
%     % iceOBCSawest1((end-ice_area_bc_decay_num+1):end)=ice_area_bc_decay;
%     iceOBCSawest1(1:iceshelf_north_end_index,:) = 0; % eliminate the land part
%     iceOBCSawest2 = iceOBCSawest1;
%     iceOBCSawest(:,1) = iceOBCSawest1;
%     iceOBCSawest(:,2) = iceOBCSawest2;
%     fid=fopen('iceOBCSawest.bin','w','b'); fwrite(fid,iceOBCSawest,acc);fclose(fid);
%     
%     
%     iceOBCSaeast = iceOBCSawest;
%     fid=fopen('iceOBCSaeast.bin','w','b'); fwrite(fid,iceOBCSaeast,acc);fclose(fid);
%     
%     iceOBCSanorth1 = 0*ones(size(bathy_combined,1),1);
%     iceOBCSanorth2 = iceOBCSanorth1;
%     iceOBCSanorth(:,1) = iceOBCSanorth1;
%     iceOBCSanorth(:,2) = iceOBCSanorth2;
%     fid=fopen('iceOBCSanorth.bin','w','b'); fwrite(fid,iceOBCSanorth,acc);fclose(fid);
%     
%     
%     % ice thickness
%     % enforcing the same pattern as ice area bc
%     
%     iceOBCShwest = 0.5*iceOBCSawest;
%     fid=fopen('iceOBCShwest.bin','w','b'); fwrite(fid,iceOBCShwest,acc);fclose(fid);
%     
%     iceOBCSheast = 0.5*iceOBCSaeast;
%     fid=fopen('iceOBCSheast.bin','w','b'); fwrite(fid,iceOBCSheast,acc);fclose(fid);
%     
%     iceOBCShnorth = 0.5*iceOBCSanorth;
%     fid=fopen('iceOBCShnorth.bin','w','b'); fwrite(fid,iceOBCShnorth,acc);fclose(fid);
%     
%     %% add on 01/18/2020- change the sea ice boundary
%     % west side concentration to 0, the only change
%     % east side still 1
%     % thickness is 0.5m on the west and east sides
%     % in order to advect sea ice out on the west instead of piling up
%     iceOBCSawest = zeros(size(iceOBCSawest));
%     fid=fopen('iceOBCSawest.bin','w','b'); fwrite(fid,iceOBCSawest,acc);fclose(fid);
%     
%     %% add on 01/19- change west sea ice thickness BC=0m
%     iceOBCShwest = zeros(size(iceOBCShwest));
%     fid=fopen('iceOBCShwest.bin','w','b'); fwrite(fid,iceOBCShwest,acc);fclose(fid);
    
    %% add on 01/22- add sea ice u-velocity on the east/west boundaries
    % the velocity is -0.3m/s here for this case, just to test
    uiceOBCSwest = 0.0*ones(size(iceOBCSawest));
    uiceOBCSwest(1:iceshelf_north_end_index,:) = 0;
    fid=fopen('uiceOBCSwest.bin','w','b'); fwrite(fid,uiceOBCSwest,acc);fclose(fid);
    
    uiceOBCSeast = uiceOBCSwest;
%     % add on 01/26- Version3, use previous output from 01/25 for east BC Uice
%     load uice_xin_353.mat
%     uiceOBCSeast = [uice_xin_353' uice_xin_353'];
    
    % add on 01/29 enforce east BC Uice=0
    uiceOBCSeast = 0.0*uiceOBCSeast;
    fid=fopen('uiceOBCSeast.bin','w','b'); fwrite(fid,uiceOBCSeast,acc);fclose(fid);
    
%     %% add on 01/25- change the east sea ice thickness to be 0
%     iceOBCSheast = 0.0*iceOBCSaeast;
%     fid=fopen('iceOBCSheast.bin','w','b'); fwrite(fid,iceOBCSheast,acc);fclose(fid);
    
    
    % add on 20200213- if at boundaries the pack ice with icetopo~=0,
    % then sea ice BC=0
    % rewrite and regenerate west sea ice BC
    icetopo_at_west_BC(:,1) = icetopo(1,:);
    icetopo_at_west_BC(:,2) = icetopo(1,:);
    
    iceOBCSawest(icetopo_at_west_BC~=0) = 0;
    fid=fopen('iceOBCSawest.bin','w','b'); fwrite(fid,iceOBCSawest,acc);fclose(fid);
    
    iceOBCShwest(icetopo_at_west_BC~=0) = 0;
    fid=fopen('iceOBCShwest.bin','w','b'); fwrite(fid,iceOBCShwest,acc);fclose(fid);
    
    uiceOBCSwest(icetopo_at_west_BC~=0) = 0;
    fid=fopen('uiceOBCSwest.bin','w','b'); fwrite(fid,uiceOBCSwest,acc);fclose(fid);
    
end


%% Add dynamical RBCS for S and T, similar to passive tracers
% note that rbcs_mask_S_T.bin is isotropic in x and y
% but rbcs_mask_ptracers.bin has spatial change near x and y boundaries
% so we separate files

rbcs_mask_S_T_2d_main = 0;

rbcs_mask_S_T_2d_rest = 1/24; % ramp to 24*3600s 1-daily

rbcs_mask_S_T_2d = function_boundary_ramp_inwards_2d_setup(bathy_combined,rbcs_mask_S_T_2d_rest,rbcs_mask_S_T_2d_main,airtemp_const_rest_length,airtemp_ramp_to_center_length);

rbcs_mask_S_T = zeros(size(bathy_combined,1),size(bathy_combined,2),nz);
for depth_in = 1:nz
    rbcs_mask_S_T(:,:,depth_in) = rbcs_mask_S_T_2d;
end
fid=fopen('rbcs_mask_S_T.bin','w','b'); fwrite(fid,rbcs_mask_S_T,acc);fclose(fid);

water_initial_temp = -1.8;
rbcs_T_file = water_initial_temp*ones(size(bathy_combined,1),size(bathy_combined,2),nz);
fid=fopen('rbcs_T_file.bin','w','b'); fwrite(fid,rbcs_T_file,acc);fclose(fid);

rbcs_S_file = zeros(size(bathy_combined,1),size(bathy_combined,2),nz);

% salinity_profile is generated from generate_stratification_halocline.m
salinity_profile = [34.0000, 34.0305, 34.0652, 34.1045, 34.1482, 34.1961, 34.2477, 34.3025, 34.3594, 34.4175, 34.4756, 34.5326, 34.5873, 34.6390, 34.6869, 34.7305, 34.7698, 34.8046, 34.8350, 34.8614, 34.8841, 34.9034, 34.9198, 34.9336, 34.9451, 34.9547, 34.9627, 34.9694, 34.9749, 34.9794, 34.9832, 34.9863, 34.9888, 34.9909, 34.9926, 34.9940, 34.9951, 34.9961, 34.9969, 34.9975, 34.9980, 34.9985, 34.9988, 34.9991, 34.9993, 34.9995, 34.9997, 34.9998, 34.9999, 35.0000];

for depth_in = 1:nz
    rbcs_S_file(:,:,depth_in) = salinity_profile(depth_in)*ones(size(bathy_combined,1),size(bathy_combined,2));
end

fid=fopen('rbcs_S_file.bin','w','b'); fwrite(fid,rbcs_S_file,acc);fclose(fid);


%% Add the parts for ptracers surface intial file

ptracers2d=ones(size(bathy_combined));
ptracers2d(:,1:iceshelf_north_end_index) = 0;

ptracers3d = zeros(size(bathy_combined,1),size(bathy_combined,2),nz);

% for inp = 1:1 % here initialized with 1 all over the surface
%
%     ptracers3d(:,:,inp) = ptracers2d;
%
% end

fid=fopen('ptracers_file.bin','w',ieee); fwrite(fid,ptracers3d,acc); fclose(fid);


%% Add mask file for Ptracers, use the below for RBCS

% The west/east/north boundary cells relaxation for ptracers
ptracers_mask = zeros(size(ptracers3d));

ptr_rbcs_ramp_length = 10;

ptracers_boundary_value = 1/24; % 24*3600s 1-daily relaxation

ptracers2d_bc = function_boundary_ramp_inwards_2d_setup(bathy_combined,ptracers_boundary_value,0,0,ptr_rbcs_ramp_length);

for depth_in = 1:nz
    ptracers_mask(:,:,depth_in) = ptracers2d_bc;
end

% The surface relaxation for constant supply of ptracers (to mimic salt)
ptracers_mask(ptracers3d~=0) = 1;

fid=fopen('rbcs_mask_ptracers.bin','w',ieee); fwrite(fid,ptracers_mask,acc); fclose(fid);




%% 20210914 - add a 2nd passive ptracers
% This passive tracer is a round shape with value 1 at the surface 
% Flag to run this part
flag_add_2nd_ptracers = 1;

if flag_add_2nd_ptracers
    
    % Add the parts for ptracers surface intial file
    ptracers2d = zeros(size(bathy_combined));
    % ptracers2d(:,1:iceshelf_north_end_index) = 0;
    
    % round shape with center and radius below
    ptix_center = 150; ptiy_center = 173; pti_radius = 25;
    
    for ptix = 1:size(ptracers2d,1)
        for ptiy = 1:size(ptracers2d,2)
            if (ptix-ptix_center)^2+(ptiy-ptiy_center)^2 <= pti_radius^2
                ptracers2d(ptix,ptiy) = 1;
            end
        end
    end
    
    % 3-D field for initial file
    ptracers3d = zeros(size(bathy_combined,1),size(bathy_combined,2),nz);
    
    for inp = 1:1 % here initialized with 1 as a round shape at the surface
    
        ptracers3d(:,:,inp) = ptracers2d;
    
    end
    
    fid=fopen('ptracers_file_2nd.bin','w',ieee); fwrite(fid,ptracers3d,acc); fclose(fid);
    
    
    %% Add mask file for Ptracers, use the below for RBCS
    
    % The west/east/north boundary cells relaxation for ptracers
    ptracers_mask = zeros(size(ptracers3d));
    
    ptr_rbcs_ramp_length = 10;
    
    ptracers_boundary_value = 1/24; % 24*3600s 1-daily relaxation
    
    ptracers2d_bc = function_boundary_ramp_inwards_2d_setup(bathy_combined,ptracers_boundary_value,0,0,ptr_rbcs_ramp_length);
    
    for depth_in = 1:nz
        ptracers_mask(:,:,depth_in) = ptracers2d_bc;
    end
    
    % The surface relaxation for constant supply of ptracers (to mimic salt)
    ptracers_mask(ptracers3d~=0) = 1;
    
    fid=fopen('rbcs_mask_ptracers_2nd.bin','w',ieee); fwrite(fid,ptracers_mask,acc); fclose(fid);
end